# remirepo spec file for php-pecl-xmldiff
#
# SPDX-FileCopyrightText:  Copyright 2013-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-xmldiff}

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  xmldiff
# After 20-dom
%global ini_name   40-%{pecl_name}.ini
%global sources    %{pecl_name}-%{version}
%global _configure ../%{sources}/configure

Summary:        XML diff and merge
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.1.5
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        BSD-2-Clause
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  make
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-dom
BuildRequires:  %{?scl_prefix}php-libxml
BuildRequires:  diffmark-devel
BuildRequires:  libxml2-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-dom%{?_isa}
Requires:       %{?scl_prefix}php-libxml%{?_isa}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
The extension is able to produce diffs of two XML documents and then to apply
the difference to the source document. The diff is a XML document containing
copy/insert/delete instruction nodes in human readable format. DOMDocument
objects, local files and strings in memory can be processed.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%package devel
Summary:       %{name} developer files (header)
Group:         Development/Libraries
Requires:      %{name}%{?_isa} = %{version}-%{release}
Requires:      %{?scl_prefix}php-devel%{?_isa}
Requires:      libxml2-devel%{?_isa}

%description devel
These are the files needed to compile programs using %{name}.


%prep
%setup -q -c

sed -e '/name="diffmark/d' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
# drop bundled library to ensure it is not used
rm -rf diffmark

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_XMLDIFF_VERSION/{s/.* "//;s/".*$//;p}' php_xmldiff.h)
if test "x${extver}" != "x%{version}%{?prever:-%{prever}}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever:-%{prever}}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --with-libdiffmark \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-libdiffmark \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Test & Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done
for i in $(grep 'role="test"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_testdir}/%{pecl_name}/$i
done


%check
cd %{sources}
# Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=dom.so \
    --define extension=../NTS/modules/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

# Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/php \
TEST_PHP_ARGS="-n -d extension=dom.so -d extension=$PWD/../NTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff

%if %{with_zts}
# Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=dom.so \
    --define extension=../ZTS/modules/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

# Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=dom.so -d extension=$PWD/../ZTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif

%files devel
%defattr(-,root,root,-)
%doc %{pecl_testdir}/%{pecl_name}
%{php_incldir}/ext/%{pecl_name}

%if %{with_zts}
%{php_ztsincldir}/ext/%{pecl_name}
%endif


%changelog
* Sun Feb 23 2025 Remi Collet <remi@remirepo.net> - 1.1.5-1
- update to 1.1.5
- re-license spec file to CECILL-2.1

* Wed Nov 27 2024 Remi Collet <remi@remirepo.net> - 1.1.4-1
- update to 1.1.4
- drop patch merged upstream

* Mon Sep 30 2024 Remi Collet <remi@remirepo.net> - 1.1.3-4
- fix PHP 8.4 build using patch from
  https://github.com/php/pecl-xml-xmldiff/pull/2

* Wed Jul 19 2023 Remi Collet <remi@remirepo.net> - 1.1.3-3
- build out of sources tree

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.1.3-2
- rebuild for 8.1.0RC1

* Mon Jan 18 2021 Remi Collet <remi@remirepo.net> - 1.1.3-1
- update to 1.1.3

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 1.1.2-16
- rebuild for PHP 8.0.0RC1

* Thu Sep 10 2020 Remi Collet <remi@remirepo.net> - 1.1.2-15
- add upstream patch for PHP 8

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.1.2-14
- rebuild for 7.4.0RC1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.1.2-13
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.1.2-12
- rebuild for 7.3.0alpha4 new ABI

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.1.2-11
- rebuild for PHP 7.2.0beta1 new API

* Fri Jun 23 2017 Remi Collet <remi@remirepo.net> - 1.1.2-10
- use devtoolset when needed (php 7.1+ on EL-7)

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.1.2-9
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 1.1.2-8
- rebuild for PHP 7.1 new API version

* Sun Mar  6 2016 Remi Collet <remi@fedoraproject.org> - 1.1.2-7
- adapt for F24

* Tue Oct 13 2015 Remi Collet <remi@fedoraproject.org> - 1.1.2-6
- rebuild for PHP 7.0.0RC5 new API version

* Fri Sep 18 2015 Remi Collet <remi@fedoraproject.org> - 1.1.2-5
- F23 rebuild with rh_layout

* Wed Jul 22 2015 Remi Collet <remi@fedoraproject.org> - 1.1.2-4
- rebuild against php 7.0.0beta2

* Wed Jul  8 2015 Remi Collet <remi@fedoraproject.org> - 1.1.2-3
- rebuild against php 7.0.0beta1

* Fri Jun 19 2015 Remi Collet <remi@fedoraproject.org> - 1.1.2-2
- allow build against rh-php56 (as more-php56)
- rebuild for "rh_layout" (php70)

* Mon Feb 09 2015 Remi Collet <remi@fedoraproject.org> - 1.1.2-1
- Update to 1.1.2 (stable)

* Mon Feb 02 2015 Remi Collet <remi@fedoraproject.org> - 1.1.1-1
- Update to 1.1.1 (stable)

* Mon Feb 02 2015 Remi Collet <remi@fedoraproject.org> - 1.1.0-1
- Update to 1.1.0 (stable)
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 0.9.2-5.1
- Fedora 21 SCL mass rebuild

* Mon Aug 25 2014 Remi Collet <rcollet@redhat.com> - 0.9.2-5
- improve SCL build

* Fri May 30 2014 Remi Collet <remi@fedoraproject.org> - 0.9.2-4
- rebuild to have NEVR > Fedora or EPEL one

* Thu Apr 17 2014 Remi Collet <remi@fedoraproject.org> - 0.9.2-3
- add numerical prefix to extension configuration file (php 5.6)

* Thu Jan  2 2014 Remi Collet <remi@fedoraproject.org> - 0.9.2-2
- adapt for SCL
- doc in pecl_docdir
- tests in pecl_test_dir (devel)

* Wed Jan  1 2014 Remi Collet <remi@fedoraproject.org> - 0.9.2-1
- Update to 0.9.2 (stable)

* Sat Nov 02 2013 Remi Collet <remi@fedoraproject.org> - 0.9.1-1
- Update to 0.9.1 (stable)
- drop our patch merged upstream

* Fri Nov 01 2013 Remi Collet <remi@fedoraproject.org> - 0.9.0-2
- fix build with php 5.3.3 in RHEL-6

* Wed Oct 02 2013 Remi Collet <remi@fedoraproject.org> - 0.9.0-1
- Update to 0.9.0 (stable)
- License now provided in upstream sources
- Drop merged patch for system libdiffmark

* Sun Sep 29 2013 Remi Collet <remi@fedoraproject.org> - 0.8.0-1
- initial package

